@@ -170,6 +170,21 @@ ChamplainMapSourceDesc OSM_OSMARENDER_DESC =
   NULL
 };
 
+static
+ChamplainMapSourceDesc OSM_MAPQUEST_DESC =
+{
+  CHAMPLAIN_MAP_SOURCE_OSM_MAPQUEST,
+  "MapQuest OSM",
+  "Data, imagery and map information provided by MapQuest, Open Street Map and contributors",
+  "http://creativecommons.org/licenses/by-sa/2.0/",
+  0,
+  17,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://otile1.mqcdn.com/tiles/1.0.0/osm/#Z#/#X#/#Y#.png",
+  NULL
+};
+
 static
 ChamplainMapSourceDesc OSM_CYCLEMAP_DESC =
 {
@@ -282,6 +297,8 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
       OSM_TRANSPORTMAP_DESC.constructor, OSM_TRANSPORTMAP_DESC.data);
   champlain_map_source_factory_register (factory, &OSM_OSMARENDER_DESC,
       OSM_OSMARENDER_DESC.constructor, OSM_OSMARENDER_DESC.data);
+  champlain_map_source_factory_register (factory, &OSM_MAPQUEST_DESC,
+      OSM_MAPQUEST_DESC.constructor, OSM_MAPQUEST_DESC.data);
 #if 0
   champlain_map_source_factory_register (factory, &OAM_DESC,
       OAM_DESC.constructor, OAM_DESC.data);
@@ -302,7 +319,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
  *
  * A method to obtain the singleton object.
  *
- * Returns: the singleton #ChamplainMapSourceFactory, it should be freed
+ * Returns: (transfer full): the singleton #ChamplainMapSourceFactory, it should be freed
  * using #g_object_unref when not needed.
  *
  * Since: 0.4
@@ -320,7 +337,7 @@ champlain_map_source_factory_dup_default (void)
  *
  * Get the list of registered map sources.
  *
- * Returns: the list of registered map sources, the items should not be freed,
+ * Returns: (transfer container) (element-type ChamplainMapSourceDesc): the list of registered map sources, the items should not be freed,
  * the list should be freed with #g_slist_free.
  *
  * Since: 0.4
@@ -340,7 +357,7 @@ champlain_map_source_factory_dup_list (ChamplainMapSourceFactory *factory)
  * The id should not contain any character that can't be in a filename as it
  * will be used as the cache directory name for that map source.
  *
- * Returns: a ready to use #ChamplainMapSource matching the given name, returns
+ * Returns: (transfer full): a ready to use #ChamplainMapSource matching the given name, returns
  * NULL is none match.
  *
  * Since: 0.4
@@ -372,9 +389,9 @@ champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
  *
  * Creates a cached map source.
  *
- * Returns: a ready to use #ChamplainMapSourceChain consisting of
- * #ChamplainFileCache, #ChamplainMapSource matching the given name, and
- * #ChamplainErrorTileSource.
+ * Returns: (transfer full): a ready to use #ChamplainMapSourceChain consisting of
+ * #ChamplainMemoryCache, #ChamplainFileCache, #ChamplainMapSource matching the given name, and
+ * an error tile source created with champlain_map_source_factory_create_error_source ().
  *
  * Since: 0.6
  */
@@ -385,6 +402,7 @@ champlain_map_source_factory_create_cached_source (ChamplainMapSourceFactory *fa
   ChamplainMapSourceChain *source_chain;
   ChamplainMapSource *tile_source;
   ChamplainMapSource *error_source;
+  ChamplainMapSource *memory_cache;
   ChamplainMapSource *file_cache;
   guint tile_size;
   ChamplainRenderer *renderer;
@@ -397,15 +415,30 @@ champlain_map_source_factory_create_cached_source (ChamplainMapSourceFactory *fa
   renderer = CHAMPLAIN_RENDERER (champlain_image_renderer_new ());
   file_cache = CHAMPLAIN_MAP_SOURCE (champlain_file_cache_new_full (100000000, NULL, renderer));
 
+  renderer = CHAMPLAIN_RENDERER (champlain_image_renderer_new ());
+  memory_cache = CHAMPLAIN_MAP_SOURCE (champlain_memory_cache_new_full (100, renderer));
+
   source_chain = champlain_map_source_chain_new ();
   champlain_map_source_chain_push (source_chain, error_source);
   champlain_map_source_chain_push (source_chain, tile_source);
   champlain_map_source_chain_push (source_chain, file_cache);
+  champlain_map_source_chain_push (source_chain, memory_cache);
 
   return CHAMPLAIN_MAP_SOURCE (source_chain);
 }
 
 
+/**
+ * champlain_map_source_factory_create_error_source:
+ * @factory: the Factory
+ * @tile_size: the size of the error tile
+ *
+ * Creates a map source generating error tiles.
+ *
+ * Returns: (transfer full): a ready to use map source generating error tiles.
+ *
+ * Since: 0.8
+ */
 ChamplainMapSource *
 champlain_map_source_factory_create_error_source (ChamplainMapSourceFactory *factory,
     guint tile_size)
@@ -424,7 +457,7 @@ champlain_map_source_factory_create_error_source (ChamplainMapSourceFactory *fac
  * champlain_map_source_factory_register:
  * @factory: A #ChamplainMapSourceFactory
  * @desc: the description of the map source
- * @constructor: the new map source constructor function
+ * @constructor: (scope notified): the new map source constructor function
  * @data: data to be passed to the constructor function, or NULL
  *
  * Registers the new map source with the given constructor.  When this map
